/*******************************************************************************
* Copyright (c) 2021, Bayerische Motoren Werke Aktiengesellschaft (BMW AG)
*
* This program and the accompanying materials are made
* available under the terms of the Eclipse Public License 2.0
* which is available at https://www.eclipse.org/legal/epl-2.0/
*
* SPDX-License-Identifier: EPL-2.0
*******************************************************************************/

//-----------------------------------------------------------------------------
/** @file  i_controller_config.h */
//-----------------------------------------------------------------------------


#ifndef MANTLEAPI_TRAFFIC_ICONTROLLERCONFIG_H
#define MANTLEAPI_TRAFFIC_ICONTROLLERCONFIG_H

#include <MantleAPI/Common/spline.h>
#include <MantleAPI/Map/i_lane_location_query_service.h>

#include <vector>

namespace mantle_api
{

struct IControllerConfig
{
    virtual ~IControllerConfig() = default;

    ILaneLocationQueryService* map_query_service{nullptr};
    std::uint64_t id{0};
};

struct NoOpControllerConfig : public IControllerConfig
{
};

struct PathControllerConfig : public IControllerConfig
{
    std::vector<mantle_api::Vec3d> waypoints{};
};

struct TrajectoryControllerConfig : public IControllerConfig
{
    std::vector<mantle_api::SplineSection> heading_splines;
    std::vector<mantle_api::SplineSection> velocity_splines;
};

}  // namespace mantle_api

#endif  // MANTLEAPI_TRAFFIC_ICONTROLLERCONFIG_H
